# HG changeset patch
# User emellor@xxxxxxxxxxxxxxxxxxxxxx
# Node ID 909664b50602a0ba4975c47a24a031a45d3a0cbe
# Parent 4ce84cc557276466a640c2fa9d4079390fd9bf6c
This fixes a path problem with the current ACM scripts.
Signed-off-by: Stefan Berger <stefanb@xxxxxxxxxx>
diff -r 4ce84cc55727 -r 909664b50602 tools/security/updategrub.sh
--- a/tools/security/updategrub.sh Wed Apr 19 22:28:22 2006 +0100
+++ b/tools/security/updategrub.sh Wed Apr 19 22:52:34 2006 +0100
@@ -41,8 +41,8 @@ Usage: $prg [-d <policies root>] <policy
default is $acmroot
<policy name> : The name of the policy, i.e. xen_null
<kernel version> : The version of the kernel to apply the policy
- against, i.e. 2.6.12.6-xen0
- If not specified, a kernel version ending with '-xen0'
+ against, i.e. 2.6.16-xen
+ If not specified, a kernel version ending with '-xen'
will be searched for in '/lib/modules'
"
}
_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog
|
diff -r 4ce84cc55727 -r 909664b50602 tools/security/labelfuncs.sh
--- a/tools/security/labelfuncs.sh Wed Apr 19 22:28:22 2006 +0100
+++ b/tools/security/labelfuncs.sh Wed Apr 19 22:52:34 2006 +0100
@@ -147,23 +147,23 @@ findGrubConf()
# will hold a pattern
# Parameters:
# 1st: the path to reach the root directory of the XEN build tree
# where linux-*-xen0 is located at
# Results:
# The variable linux holds then name and version of the compiled
-# kernel, i.e., 'vmlinuz-2.6.12-xen0'
+# kernel, i.e., 'vmlinuz-2.6.12-xen'
getLinuxVersion ()
{
local path
local versionfile
local lnx
if [ "$1" == "" ]; then
- path="/lib/modules/*-xen0"
+ path="/lib/modules/*-xen"
else
path="/lib/modules/$1"
fi
linux=""
- for f in $path/linux-*-xen0 ; do
+ for f in $path ; do
versionfile=$f/build/include/linux/version.h
if [ -r $versionfile ]; then
lnx=`cat $versionfile | \
@@ -178,7 +178,7 @@ getLinuxVersion ()
numbers[2], \
numbers[3]); \
} else { \
- printf("%s.%s.%s[.0-9]*-xen0",\
+ printf("%s.%s.%s[.0-9]*-xen", \
numbers[1], \
numbers[2], \
numbers[3]); \
@@ -192,7 +192,7 @@ getLinuxVersion ()
done
#Last resort.
- linux="vmlinuz-2.[45678].[0-9]*[.0-9]*-xen0$"
+ linux="vmlinuz-2.[45678].[0-9]*[.0-9]*-xen$"
}
@@ -147,23 +147,23 @@ findGrubConf()
# Parameters:
# 1st: the path to reach the root directory of the XEN build tree
-# where linux-*-xen0 is located at
+# where linux-*-xen is located at
# Results:
# The variable linux holds then name and version of the compiled